Index: /trunk/include/functions_html.inc.php
===================================================================
--- /trunk/include/functions_html.inc.php	(revision 25601)
+++ /trunk/include/functions_html.inc.php	(revision 25602)
@@ -336,5 +336,5 @@
 /**
  * Exits the current script with 403 code.
- * TODO : nice display if $template loaded
+ * @todo nice display if $template loaded
  *
  * @param string $msg
@@ -355,5 +355,5 @@
 /**
  * Exits the current script with 400 code.
- * TODO : nice display if $template loaded
+ * @todo nice display if $template loaded
  *
  * @param string $msg
@@ -374,5 +374,5 @@
 /**
  * Exits the current script with 404 code.
- * TODO : nice display if $template loaded
+ * @todo nice display if $template loaded
  *
  * @param string $msg
@@ -393,5 +393,5 @@
 /**
  * Exits the current script with 500 code.
- * TODO : nice display if $template loaded
+ * @todo nice display if $template loaded
  *
  * @param string $msg
Index: /trunk/include/functions_notification.inc.php
===================================================================
--- /trunk/include/functions_notification.inc.php	(revision 25601)
+++ /trunk/include/functions_notification.inc.php	(revision 25602)
@@ -25,6 +25,4 @@
  * @package functions\notification
  */
- 
-// TODO : use a cache for all data returned by custom_notification_query()
 
 
@@ -55,4 +53,5 @@
 /**
  * Execute custom notification query.
+ * @todo use a cache for all data returned by custom_notification_query()
  *
  * @param string $action 'count', 'info'
@@ -344,5 +343,5 @@
  * updated categories. Administrators are also informed about: number of
  * unvalidated comments, number of new users.
- * TODO : number of unvalidated elements
+ * @todo number of unvalidated elements
  *
  * @param string $start (mysql datetime format)
@@ -389,5 +388,5 @@
  * updated categories. Administrators are also informed about: number of
  * unvalidated comments, number of new users.
- * TODO : number of unvalidated elements
+ * @todo number of unvalidated elements
  *
  * @param string $start (mysql datetime format)
@@ -518,5 +517,5 @@
 /**
  * Returns html description about recently published elements grouped by post date.
- * TODO : clean up HTML output, currently messy and invalid !
+ * @todo clean up HTML output, currently messy and invalid !
  *
  * @param array $date_detail returned value of get_recent_post_dates()
Index: /trunk/include/functions_plugins.inc.php
===================================================================
--- /trunk/include/functions_plugins.inc.php	(revision 25601)
+++ /trunk/include/functions_plugins.inc.php	(revision 25602)
@@ -239,7 +239,10 @@
 /**
  * Triggers a modifier event and calls all registered event handlers.
  * trigger_modify() is used as a modifier: it allows to transmit _$data_
  * through all handlers, thus each handler MUST return a value,
  * optional _$args_ are not transmitted.
+ *
+ * @since 2.6
+ * @todo remove trigger_event()
  *
  * @param string $event
@@ -248,4 +251,13 @@
  * @return mixed $data 
  */
+function trigger_change($event, $data=null)
+{
+  return call_user_func_array('trigger_event', func_get_args());
+}
+
+/**
+ * @deprecated 2.6
+ * @see trigger_change
+ */
 function trigger_event($event, $data=null)
 {
@@ -280,9 +292,21 @@
 
 /**
  * Triggers an notifier event and calls all registered event handlers.
  * trigger_action() is only used as a notifier, no modification of data is possible
  *
  * @param string $event
  * @param mixed $args,... optional arguments
+ */
+function trigger_notify($event)
+{
+  return call_user_func_array('trigger_action', func_get_args());
+}
+
+/**
+ * @deprecated 2.6
+ * @see trigger_notify
  */
 function trigger_action($event)
@@ -239,7 +239,10 @@
 /**
  * Triggers a modifier event and calls all registered event handlers.
- * trigger_modify() is used as a modifier: it allows to transmit _$data_
+ * trigger_change() is used as a modifier: it allows to transmit _$data_
  * through all handlers, thus each handler MUST return a value,
  * optional _$args_ are not transmitted.
@@ -280,9 +292,21 @@
 
 /**
- * Triggers an notifier event and calls all registered event handlers.
- * trigger_action() is only used as a notifier, no modification of data is possible
+ * Triggers a notifier event and calls all registered event handlers.
+ * trigger_notify() is only used as a notifier, no modification of data is possible
+ *
+ * @since 2.6
+ * @todo remove trigger_action()
  *
  * @param string $event
